==> gnome-graphics-0.20.tar.gz: gnome-graphics-0.20/ee/globals.c <==
/*****************             Electirc Eyes           ***********************/
/* This software is Copyright (C) 1998 but The Rasterman (Carsten Haitzler). */
/* This software falls under the GNU Public License. Please read the COPYING */
/* file for more information                                                 */
/*****************************************************************************/
#include "ee.h"

char                   *current_dir;
GtkWidget              *window_image;
struct _current_image  current;
GList                  *image_list;
GtkWidget              *menu_main;
GtkWidget              *app;
GtkWidget              *window_edit;
GdkPixmap              *brightness_pmap;
GdkPixmap              *brightness_mask;
GdkPixmap              *contrast_pmap;
GdkPixmap              *contrast_mask;
GdkPixmap              *gamma_pmap;
GdkPixmap              *gamma_mask;
GdkImlibImage          *red_curve;
GdkImlibImage          *green_curve;
GdkImlibImage          *blue_curve;
GdkPixmap              *red_curve_pmap;
GdkPixmap              *green_curve_pmap;
GdkPixmap              *blue_curve_pmap;
GtkWidget              *red_view;
GtkWidget              *green_view;
GtkWidget              *blue_view;
GtkObject              *adjusters[12];
GtkWidget              *sliders[12];
char                   autoapply=0;
GtkAcceleratorTable    *image_accel;
GtkAcceleratorTable    *edit_accel;
GtkWidget              *tips;
GtkWidget              *list=NULL;
char                   mods_changed=1;
char                   in_init=1;
guint                  slide_timer=0;
guint32                silde_speed=4000;
int                    num_categories;
char                   **categories;
char                   fixed_aspect=0;
GtkObject              *width_adj,*height_adj;
GtkWidget              *width_wid,*height_wid;
GtkObject              *cropx_adj,*cropy_adj,*cropw_adj,*croph_adj;
GtkWidget              *cropx_wid,*cropy_wid,*cropw_wid,*croph_wid;
char                   mod_width=0,mod_height=0;
char                   mod_cx=0,mod_cy=0,mod_cw=0,mod_ch=0;
char                   incrop=0,cstart=0;
int                    crop_x=0,crop_y=0,crop_w=-1,crop_h=-1;
int                    thumb_w=80,thumb_h=80;
GtkWidget              *window_thumbs=NULL;
GtkWidget              *thumbs_box;
GtkWidget              *fsel=NULL;
char                   loadsave=0;
GtkWidget              *aboutwin;
GtkWidget              *window_config;
char                   keepsize=0;

==> gnome-graphics-0.25.tar.gz: gnome-graphics-0.25/ee/globals.c <==
/*****************             Electirc Eyes           ***********************/
/* This software is Copyright (C) 1998 but The Rasterman (Carsten Haitzler). */
/* This software falls under the GNU Public License. Please read the COPYING */
/* file for more information                                                 */
/*****************************************************************************/
#include "ee.h"

char                   *current_dir;
GtkWidget              *window_image;
struct _current_image  current;
GList                  *image_list;
GtkWidget              *menu_main;
GtkWidget              *app;
GtkWidget              *window_edit;
GdkPixmap              *brightness_pmap;
GdkPixmap              *brightness_mask;
GdkPixmap              *contrast_pmap;
GdkPixmap              *contrast_mask;
GdkPixmap              *gamma_pmap;
GdkPixmap              *gamma_mask;
GdkImlibImage          *red_curve;
GdkImlibImage          *green_curve;
GdkImlibImage          *blue_curve;
GdkPixmap              *red_curve_pmap;
GdkPixmap              *green_curve_pmap;
GdkPixmap              *blue_curve_pmap;
GtkWidget              *red_view;
GtkWidget              *green_view;
GtkWidget              *blue_view;
GtkObject              *adjusters[12];
GtkWidget              *sliders[12];
char                   autoapply=0;
#ifdef GTK_HAVE_FEATURES_1_1_0
GtkAccelGroup          *image_accel;
GtkAccelGroup          *edit_accel;
#else
GtkAcceleratorTable    *image_accel;
GtkAcceleratorTable    *edit_accel;
#endif
GtkWidget              *tips;
GtkWidget              *list=NULL;
char                   mods_changed=1;
char                   in_init=1;
guint                  slide_timer=0;
guint32                silde_speed=4000;
int                    num_categories;
char                   **categories;
char                   fixed_aspect=0;
char                   correcting_aspect=0;
GtkObject              *width_adj,*height_adj;
GtkWidget              *width_wid,*height_wid;
GtkObject              *cropx_adj,*cropy_adj,*cropw_adj,*croph_adj;
GtkWidget              *cropx_wid,*cropy_wid,*cropw_wid,*croph_wid;
char                   mod_width=0,mod_height=0;
char                   mod_cx=0,mod_cy=0,mod_cw=0,mod_ch=0;
char                   incrop=0,cstart=0;
int                    crop_x=0,crop_y=0,crop_w=-1,crop_h=-1;
int                    thumb_w=80,thumb_h=80;
GtkWidget              *window_thumbs=NULL;
GtkWidget              *thumbs_box;
GtkWidget              *fsel=NULL;
char                   loadsave=0;
GtkWidget              *aboutwin;
GtkWidget              *window_config;
char                   keepsize=0;
char                   *ls_wildcard;
